vfbLib.parsers.glyph.MaskParser
===============================

.. currentmodule:: vfbLib.parsers.glyph

.. autoclass:: MaskParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MaskParser.__init__
      ~MaskParser.parse
      ~MaskParser.parse_binary
      ~MaskParser.parse_components
      ~MaskParser.parse_guides
      ~MaskParser.parse_hex
      ~MaskParser.parse_hints
      ~MaskParser.parse_instructions
      ~MaskParser.parse_kerning
      ~MaskParser.parse_metrics
      ~MaskParser.parse_outlines
      ~MaskParser.read_double
      ~MaskParser.read_doubles
      ~MaskParser.read_float
      ~MaskParser.read_floats
      ~MaskParser.read_int16
      ~MaskParser.read_int32
      ~MaskParser.read_int8
      ~MaskParser.read_str
      ~MaskParser.read_str_all
      ~MaskParser.read_uint16
      ~MaskParser.read_uint32
      ~MaskParser.read_uint8
      ~MaskParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MaskParser.encoding
      ~MaskParser.master_count
      ~MaskParser.stream
      ~MaskParser.ttStemsH_count
      ~MaskParser.ttStemsV_count
   
   